window.Gleam.initSearch([{"doc":"gleam_javascript","title":"gleam_javascript","content":"# Gleam JavaScript 🌼\n\nWork with JavaScript types and values in Gleam.\n\n## Installation\n\nAdd this package to your Gleam project.\n\n```shell\ngleam add gleam_javascript\n```\n\n## Features\n\nThis library contains modules for working with...\n\n- Arrays\n- Mutable references\n- Promises\n- Symbols\n- `typeof`\n","url":"index.html"},{"doc":"gleam/javascript","title":"Symbol","content":"pub type Symbol\n Symbols are special unique values in JavaScript.\n\n For further information view the MDN documentation: \n &lt;https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Symbol&gt;\n\n\nSynonyms:\ngleam/javascript.Symbol\ngleam/javascript Symbol","url":"gleam/javascript.html#Symbol"},{"doc":"gleam/javascript","title":"TypeOf","content":"pub type TypeOf {\n  UndefinedType\n  ObjectType\n  BooleanType\n  NumberType\n  BigIntType\n  StringType\n  SymbolType\n  FunctionType\n}\n The variants that `type_of` can return.\nUndefinedType\n It is the value `undefined`.\n\nObjectType\n It is some object, or it is `null`.\n\nBooleanType\n It is either `true` or `false`.\n\nNumberType\n It is some number, a 64 bit float.\n\nBigIntType\n It is a JavaScript big-integer.\n\nStringType\n It is a string.\n\nSymbolType\n It is a JavaScript symbol.\n\nFunctionType\n It is a function of unknown argument types and return type.\n\nSynonyms:\ngleam/javascript.TypeOf\ngleam/javascript TypeOf","url":"gleam/javascript.html#TypeOf"},{"doc":"gleam/javascript","title":"get_symbol","content":"pub fn get_symbol(a: String) -&gt; Symbol\n Use the JavaScript `Symbol.for` method to look up a symbol with the given\n string name, creating a new one if one does exist.\n\n For further information see the MDN documentation:\n &lt;https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Symbol/for&gt;\n\nSynonyms:\ngleam/javascript.get_symbol\ngleam/javascript get_symbol","url":"gleam/javascript.html#get_symbol"},{"doc":"gleam/javascript","title":"type_of","content":"pub fn type_of(a: a) -&gt; TypeOf\n Determine what category of JavaScript type a value belongs to.\n\n This uses the JavaScript `typeof` operator and has limited accuracy. It\n cannot tell you anything about what Gleam type a value has.\n\n For further information view the MDN documentation: \n &lt;https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Symbol&gt;\n\nSynonyms:\ngleam/javascript.type_of\ngleam/javascript type_of","url":"gleam/javascript.html#type_of"},{"doc":"gleam/javascript","title":"gleam/javascript","content":"","url":"gleam/javascript.html"},{"doc":"gleam/javascript/array","title":"Array","content":"pub type Array(element)\n A JavaScript array, in Gleam!\n\n Unlike most data structures in Gleam this one is mutable.\n\n\nSynonyms:\ngleam/javascript/array.Array\ngleam/javascript/array Array","url":"gleam/javascript/array.html#Array"},{"doc":"gleam/javascript/array","title":"fold","content":"pub fn fold(\n  over over: Array(a),\n  from from: b,\n  with with: fn(b, a) -&gt; b,\n) -&gt; b\n Reduces a list of elements into a single value by calling a given function\n on each element, going from left to right.\n\n `fold(from_list([1, 2, 3]), 0, add)` is the equivalent of\n `add(add(add(0, 1), 2), 3)`.\n\n Runs in linear time.\n\nSynonyms:\ngleam/javascript/array.fold\ngleam/javascript/array fold","url":"gleam/javascript/array.html#fold"},{"doc":"gleam/javascript/array","title":"fold_right","content":"pub fn fold_right(\n  over over: Array(a),\n  from from: b,\n  with with: fn(b, a) -&gt; b,\n) -&gt; b\n Reduces a list of elements into a single value by calling a given function\n on each element, going from right to left.\n\n `fold_right(from_list([1, 2, 3]), 0, add)` is the equivalent of\n `add(add(add(0, 3), 2), 1)`.\n\n Runs in linear time.\n\nSynonyms:\ngleam/javascript/array.fold_right\ngleam/javascript/array fold_right","url":"gleam/javascript/array.html#fold_right"},{"doc":"gleam/javascript/array","title":"from_list","content":"pub fn from_list(a: List(a)) -&gt; Array(a)\n Convert a Gleam list to a JavaScript array.\n\n Runs in linear time.\n\nSynonyms:\ngleam/javascript/array.from_list\ngleam/javascript/array from_list","url":"gleam/javascript/array.html#from_list"},{"doc":"gleam/javascript/array","title":"get","content":"pub fn get(a: Array(a), b: Int) -&gt; Result(a, Nil)\n Get the element at the given index.\n\n # Examples\n\n \n &gt; get(from_list([2, 4, 6]), 1)\n Ok(4)\n \n\n \n &gt; get(from_list([2, 4, 6]), 4)\n Error(Nil)\n \n\nSynonyms:\ngleam/javascript/array.get\ngleam/javascript/array get","url":"gleam/javascript/array.html#get"},{"doc":"gleam/javascript/array","title":"map","content":"pub fn map(a: Array(a), with with: fn(a) -&gt; b) -&gt; Array(b)\n Returns a new array containing only the elements of the first array after\n the function has been applied to each one.\n\n Runs in linear time.\n\n # Examples\n\n \n &gt; map(from_list([2, 4, 6]), fn(x) { x * 2 })\n from_list([4, 8, 12])\n \n\nSynonyms:\ngleam/javascript/array.map\ngleam/javascript/array map","url":"gleam/javascript/array.html#map"},{"doc":"gleam/javascript/array","title":"size","content":"pub fn size(a: Array(a)) -&gt; Int\n Get the number of elements in the array.\n\n Runs in constant time.\n\nSynonyms:\ngleam/javascript/array.size\ngleam/javascript/array size","url":"gleam/javascript/array.html#size"},{"doc":"gleam/javascript/array","title":"to_list","content":"pub fn to_list(items: Array(a)) -&gt; List(a)\n Convert a JavaScript array to a Gleam list.\n\n Runs in linear time.\n\nSynonyms:\ngleam/javascript/array.to_list\ngleam/javascript/array to_list","url":"gleam/javascript/array.html#to_list"},{"doc":"gleam/javascript/array","title":"gleam/javascript/array","content":"","url":"gleam/javascript/array.html"},{"doc":"gleam/javascript/map","title":"Map","content":"pub type Map(key, value)\n The JavaScript `Map` type, a **mutable** collection of keys and values.\n\n Most the time you should use the `Dict` type from `gleam/dict` in the Gleam\n standard library. This type may still be useful for JavaScript interop.\n\n For further information view the MDN documentation: \n &lt;https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Map&gt;\n\n\nSynonyms:\ngleam/javascript/map.Map\ngleam/javascript/map Map","url":"gleam/javascript/map.html#Map"},{"doc":"gleam/javascript/map","title":"get","content":"pub fn get(a: Map(a, b), b: a) -&gt; Result(b, Nil)\n Get the value for a given key in the `Map`.\n\nSynonyms:\ngleam/javascript/map.get\ngleam/javascript/map get","url":"gleam/javascript/map.html#get"},{"doc":"gleam/javascript/map","title":"new","content":"pub fn new() -&gt; Map(a, b)\n Create a new `Map` with no contained values.\n\nSynonyms:\ngleam/javascript/map.new\ngleam/javascript/map new","url":"gleam/javascript/map.html#new"},{"doc":"gleam/javascript/map","title":"set","content":"pub fn set(a: Map(a, b), b: a, c: b) -&gt; Map(a, b)\n Insert a new key and value into the `Map`.\n\n **NOTE:** This function will mutate the `Map` rather than immutably\n updating it.\n\nSynonyms:\ngleam/javascript/map.set\ngleam/javascript/map set","url":"gleam/javascript/map.html#set"},{"doc":"gleam/javascript/map","title":"size","content":"pub fn size(a: Map(a, b)) -&gt; Int\n Get the number of key-value pairs in the `Map`.\n\nSynonyms:\ngleam/javascript/map.size\ngleam/javascript/map size","url":"gleam/javascript/map.html#size"},{"doc":"gleam/javascript/map","title":"gleam/javascript/map","content":"","url":"gleam/javascript/map.html"},{"doc":"gleam/javascript/promise","title":"Promise","content":"pub type Promise(value)\n JavaScript promises represent the result of an asynchronous operation which\n returns a value, either now or at some point in the future. In practice\n they are the foundation of concurrency in JavaScript.\n\n This library assumes you have some familiarity with JavaScript promises. If\n you are not then you may want to take the time to learn about them outside of\n Gleam. \n\n The Gleam promise type is generic over the type of value it resolves. It is\n not generic over the error type as any Gleam panic or JavaScript exception\n could alter the error value in an way that undermines the type, making it \n unsound and untypable.\n If you want to represent success and failure with promises use a Gleam\n `Result` inside of a promise.\n\n For further information view the MDN documentation: \n &lt;https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Promise&gt;\n\n\nSynonyms:\ngleam/javascript/promise.Promise\ngleam/javascript/promise Promise","url":"gleam/javascript/promise.html#Promise"},{"doc":"gleam/javascript/promise","title":"await","content":"pub fn await(a: Promise(a), b: fn(a) -&gt; Promise(b)) -&gt; Promise(b)\n Chain a second asynchronous operation onto a promise, so it runs after the\n promise has resolved.\n\n This is the equivilent of the `promise.then` JavaScript method.\n\nSynonyms:\ngleam/javascript/promise.await\ngleam/javascript/promise await","url":"gleam/javascript/promise.html#await"},{"doc":"gleam/javascript/promise","title":"await2","content":"pub fn await2(a: Promise(a), b: Promise(b)) -&gt; Promise(#(a, b))\n Chain an asynchronous operation onto 2 promises, so it runs after the\n promises have resolved.\n\n This is the equivilent of the `Promise.all` JavaScript static method.\n\nSynonyms:\ngleam/javascript/promise.await2\ngleam/javascript/promise await2","url":"gleam/javascript/promise.html#await2"},{"doc":"gleam/javascript/promise","title":"await3","content":"pub fn await3(\n  a: Promise(a),\n  b: Promise(b),\n  c: Promise(c),\n) -&gt; Promise(#(a, b, c))\n Chain an asynchronous operation onto 3 promises, so it runs after the\n promises have resolved.\n\n This is the equivilent of the `Promise.all` JavaScript static method.\n\nSynonyms:\ngleam/javascript/promise.await3\ngleam/javascript/promise await3","url":"gleam/javascript/promise.html#await3"},{"doc":"gleam/javascript/promise","title":"await4","content":"pub fn await4(\n  a: Promise(a),\n  b: Promise(b),\n  c: Promise(c),\n  d: Promise(d),\n) -&gt; Promise(#(a, b, c, d))\n Chain an asynchronous operation onto 4 promises, so it runs after the\n promises have resolved.\n\n This is the equivilent of the `Promise.all` JavaScript static method.\n\nSynonyms:\ngleam/javascript/promise.await4\ngleam/javascript/promise await4","url":"gleam/javascript/promise.html#await4"},{"doc":"gleam/javascript/promise","title":"await5","content":"pub fn await5(\n  a: Promise(a),\n  b: Promise(b),\n  c: Promise(c),\n  d: Promise(d),\n  e: Promise(e),\n) -&gt; Promise(#(a, b, c, d, e))\n Chain an asynchronous operation onto 5 promises, so it runs after the\n promises have resolved.\n\n This is the equivilent of the `Promise.all` JavaScript static method.\n\nSynonyms:\ngleam/javascript/promise.await5\ngleam/javascript/promise await5","url":"gleam/javascript/promise.html#await5"},{"doc":"gleam/javascript/promise","title":"await6","content":"pub fn await6(\n  a: Promise(a),\n  b: Promise(b),\n  c: Promise(c),\n  d: Promise(d),\n  e: Promise(e),\n  f: Promise(f),\n) -&gt; Promise(#(a, b, c, d, e, f))\n Chain an asynchronous operation onto 6 promises, so it runs after the\n promises have resolved.\n\n This is the equivilent of the `Promise.all` JavaScript static method.\n\nSynonyms:\ngleam/javascript/promise.await6\ngleam/javascript/promise await6","url":"gleam/javascript/promise.html#await6"},{"doc":"gleam/javascript/promise","title":"await_array","content":"pub fn await_array(a: Array(Promise(a))) -&gt; Promise(Array(a))\n Chain an asynchronous operation onto an array of promises, so it runs after the\n promises have resolved.\n\n This is the equivilent of the `Promise.all` JavaScript static method.\n\nSynonyms:\ngleam/javascript/promise.await_array\ngleam/javascript/promise await_array","url":"gleam/javascript/promise.html#await_array"},{"doc":"gleam/javascript/promise","title":"await_list","content":"pub fn await_list(xs: List(Promise(a))) -&gt; Promise(List(a))\n Chain an asynchronous operation onto an list of promises, so it runs after the\n promises have resolved.\n\n This is the equivilent of the `Promise.all` JavaScript static method.\n\nSynonyms:\ngleam/javascript/promise.await_list\ngleam/javascript/promise await_list","url":"gleam/javascript/promise.html#await_list"},{"doc":"gleam/javascript/promise","title":"map","content":"pub fn map(a: Promise(a), b: fn(a) -&gt; b) -&gt; Promise(b)\n Run a function on the value a promise resolves to, after it has resolved.\n The value returned becomes the new value contained by the promise.\n\nSynonyms:\ngleam/javascript/promise.map\ngleam/javascript/promise map","url":"gleam/javascript/promise.html#map"},{"doc":"gleam/javascript/promise","title":"map_try","content":"pub fn map_try(\n  promise: Promise(Result(a, b)),\n  callback: fn(a) -&gt; Result(c, b),\n) -&gt; Promise(Result(c, b))\n Run a function on the value a promise resolves to, after it has resolved.\n\n The function is only called if the value is `Ok`, and the returned becomes\n the new value contained by the promise.\n\n This is a convenience functin that combines the `map` function with `result.try`.\n\nSynonyms:\ngleam/javascript/promise.map_try\ngleam/javascript/promise map_try","url":"gleam/javascript/promise.html#map_try"},{"doc":"gleam/javascript/promise","title":"new","content":"pub fn new(a: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Promise(a)\n Create a new promise from a callback function. The callback function itself\n takes a second function as an argument, and when that second function is\n called with a value then the promise resolves with that value.\n\n This function is useful for converting code that uses callbacks into code\n that uses promises.\n\nSynonyms:\ngleam/javascript/promise.new\ngleam/javascript/promise new","url":"gleam/javascript/promise.html#new"},{"doc":"gleam/javascript/promise","title":"race2","content":"pub fn race2(a: Promise(a), b: Promise(a)) -&gt; Promise(a)\n\nSynonyms:\ngleam/javascript/promise.race2\ngleam/javascript/promise race2","url":"gleam/javascript/promise.html#race2"},{"doc":"gleam/javascript/promise","title":"race3","content":"pub fn race3(\n  a: Promise(a),\n  b: Promise(a),\n  c: Promise(a),\n) -&gt; Promise(a)\n\nSynonyms:\ngleam/javascript/promise.race3\ngleam/javascript/promise race3","url":"gleam/javascript/promise.html#race3"},{"doc":"gleam/javascript/promise","title":"race4","content":"pub fn race4(\n  a: Promise(a),\n  b: Promise(a),\n  c: Promise(a),\n  d: Promise(a),\n) -&gt; Promise(a)\n\nSynonyms:\ngleam/javascript/promise.race4\ngleam/javascript/promise race4","url":"gleam/javascript/promise.html#race4"},{"doc":"gleam/javascript/promise","title":"race5","content":"pub fn race5(\n  a: Promise(a),\n  b: Promise(a),\n  c: Promise(a),\n  d: Promise(a),\n  e: Promise(a),\n) -&gt; Promise(a)\n\nSynonyms:\ngleam/javascript/promise.race5\ngleam/javascript/promise race5","url":"gleam/javascript/promise.html#race5"},{"doc":"gleam/javascript/promise","title":"race6","content":"pub fn race6(\n  a: Promise(a),\n  b: Promise(a),\n  c: Promise(a),\n  d: Promise(a),\n  e: Promise(a),\n  f: Promise(a),\n) -&gt; Promise(a)\n\nSynonyms:\ngleam/javascript/promise.race6\ngleam/javascript/promise race6","url":"gleam/javascript/promise.html#race6"},{"doc":"gleam/javascript/promise","title":"race_array","content":"pub fn race_array(a: Array(Promise(a))) -&gt; Promise(a)\n\nSynonyms:\ngleam/javascript/promise.race_array\ngleam/javascript/promise race_array","url":"gleam/javascript/promise.html#race_array"},{"doc":"gleam/javascript/promise","title":"race_list","content":"pub fn race_list(a: List(Promise(a))) -&gt; Promise(a)\n\nSynonyms:\ngleam/javascript/promise.race_list\ngleam/javascript/promise race_list","url":"gleam/javascript/promise.html#race_list"},{"doc":"gleam/javascript/promise","title":"rescue","content":"pub fn rescue(a: Promise(a), b: fn(Dynamic) -&gt; a) -&gt; Promise(a)\n If the promise is in an error state then apply a function to convert the\n error value back into valid value, making the promise healthy again.\n\n This is the equivilent of the `promise.catch` JavaScript method.\n\nSynonyms:\ngleam/javascript/promise.rescue\ngleam/javascript/promise rescue","url":"gleam/javascript/promise.html#rescue"},{"doc":"gleam/javascript/promise","title":"resolve","content":"pub fn resolve(a: a) -&gt; Promise(a)\n Create a promise that resolves immediately.\n\nSynonyms:\ngleam/javascript/promise.resolve\ngleam/javascript/promise resolve","url":"gleam/javascript/promise.html#resolve"},{"doc":"gleam/javascript/promise","title":"start","content":"pub fn start() -&gt; #(Promise(a), fn(a) -&gt; Nil)\n Create a new promise and resolve function. The first time the resolve function\n is called the promise resolves with that value.\n\n This function is useful in cases where a reference to the promise and resolver\n are needed.\n\nSynonyms:\ngleam/javascript/promise.start\ngleam/javascript/promise start","url":"gleam/javascript/promise.html#start"},{"doc":"gleam/javascript/promise","title":"tap","content":"pub fn tap(\n  promise: Promise(a),\n  callback: fn(a) -&gt; b,\n) -&gt; Promise(a)\n Run a function on the value a promise resolves to, after it has resolved.\n The value returned is discarded.\n\nSynonyms:\ngleam/javascript/promise.tap\ngleam/javascript/promise tap","url":"gleam/javascript/promise.html#tap"},{"doc":"gleam/javascript/promise","title":"try_await","content":"pub fn try_await(\n  promise: Promise(Result(a, b)),\n  callback: fn(a) -&gt; Promise(Result(c, b)),\n) -&gt; Promise(Result(c, b))\n Run a promise returning function on the value a promise resolves to, after\n it has resolved.\n\n The function is only called if the value is `Ok`, and the returned becomes\n the new value contained by the promise.\n\n This is a convenience functin that combines the `await` function with\n `result.try`.\n\nSynonyms:\ngleam/javascript/promise.try_await\ngleam/javascript/promise try_await","url":"gleam/javascript/promise.html#try_await"},{"doc":"gleam/javascript/promise","title":"wait","content":"pub fn wait(delay: Int) -&gt; Promise(Nil)\n Create a promise that will resolve after a delay.\n The delay is specified in milliseconds\n\nSynonyms:\ngleam/javascript/promise.wait\ngleam/javascript/promise wait","url":"gleam/javascript/promise.html#wait"},{"doc":"gleam/javascript/promise","title":"gleam/javascript/promise","content":"","url":"gleam/javascript/promise.html"}]);